@@ -12,6 +12,7 @@ from netifaces import interfaces, ifaddresses, AF_INET
 
 LOCKFILE = "/tmp/touchandgo"
 
+
 def get_free_port():
   s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
   s.bind(('localhost', 0))
@@ -19,6 +20,7 @@ def get_free_port():
   s.close()
   return port
 
+
 def get_interface():
     for ifaceName in interfaces():
         addresses = ifaddresses(ifaceName)
@@ -27,6 +29,7 @@ def get_interface():
                 if item.get('netmask') is not None and not item['addr'].startswith("127") and not item['addr'].startswith(":"):
                     return item['addr']
 
+
 def is_process_running(process_id):
     try:
         os.kill(process_id, 0)
@@ -34,6 +37,7 @@ def is_process_running(process_id):
     except OSError:
         return False
 
+
 def execute(command):
     process = Popen(command, shell=True, stdout=PIPE, stderr=STDOUT)
     print("Running peerflix")
@@ -48,7 +52,7 @@ def execute(command):
 
     output = process.communicate()[0]
     exitCode = process.returncode
-    print output, exitCode
+    #print output, exitCode
 
 
 def daemonize(args, callback):
